@@ -7,7 +7,7 @@ from pandas.core.frame import DataFrame
 from tqdm import tqdm
 
 from eda_report.multivariate import MultiVariable
-from eda_report.plotting import PlotMultiVariate, PlotUnivariate
+from eda_report.plotting import PlotMultiVariable, PlotVariable
 from eda_report.univariate import Variable
 from eda_report.validate import validate_target_variable
 
@@ -50,7 +50,7 @@ class ReportContent:
         )
         self.TITLE = title
         self.intro_text = self._get_introductory_summary()
-        self.multivariate_graphs = PlotMultiVariate(
+        self.multivariate_graphs = PlotMultiVariable(
             self.variables,
             graph_color=self.GRAPH_COLOR,
             hue=self.TARGET_VARIABLE,
@@ -107,7 +107,7 @@ class ReportContent:
                 f"{name.capitalize()} is a {var.var_type} variable with"
                 f" {unique_vals}. {var.missing} of its values are missing."
             ),
-            "graphs": PlotUnivariate(
+            "graphs": PlotVariable(
                 variable=var,
                 graph_color=self.GRAPH_COLOR,
                 hue=self.TARGET_VARIABLE,
@@ -357,10 +357,12 @@ class ReportDocument(ReportContent):
             Flags whether the first row is a header, by default False.
         """
         if header:
-            data.loc["", :] = data.columns
-            # Sort the index in ascending order, to ensure that column names
-            # end up as the first row.
-            data.sort_index(inplace=True)
+            # Add a row of column labels
+            data_with_header = data.copy()
+            data_with_header.loc["", :] = data.columns
+
+            # Ensure that column labels are in the first row
+            data = data_with_header.sort_index()
 
         table = self.document.add_table(
             rows=len(data),
